@@ -5,7 +5,7 @@ oer - IRC bot
 See ftp://nic.funet.fi/pub/unix/irc/docs/FAQ.gz section 11 for the
 definition of the word bot.
 
-Copyright (C) 2000-2001 EQU <equ@equnet.org>
+Copyright (C) 2000-2002 EQU <equ@equnet.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -38,6 +38,7 @@ int isctcp(char *);
 int wordcount(char *);
 int parse(char *, int, char *, char *, int, int);
 int issamenickandhost(char *, char *, char *, char *);
+int issimilarstring(char *, char *);
 unsigned int longestword(char *);
 unsigned int isgoodquote(char *);
 void striplf(char *);
@@ -565,3 +566,33 @@ unsigned int isgoodquote(char *quote)
 		}
 		return 1;
 }
+
+int issimilarstring(char *s1, char *s2)
+{
+        int s1len;
+        int s2len;
+        int fract;
+        /* first do a compare for exact match */
+        if(!strcasecmp(s1, s2) || !strcasecmp(s2, s1)) {
+                return 1;
+        }
+        s1len = strlen(s1);
+        s2len = strlen(s2);
+        if(s1len < 8 || s2len < 8) {
+                return 0;
+        }
+        /* then do a compare of s1 and s2 beginning
+           at pos 0 + len/8 and ending at pos len - len/8 */
+        if(s1len > s2len) {
+                fract = s2len >> 3;
+                if(!strncasecmp(s1 + fract, s2 + fract, s1len - (fract << 1))) {
+                        return 1;
+                }
+        } else {
+                fract = s1len >> 3;
+                if(!strncasecmp(s2 + fract, s1 + fract, s2len - (fract << 1))) {
+                        return 1;
+                }
+        }
+        return 0;
+}
