@@ -240,6 +240,7 @@ enum OER_TIMED_PRIORITIES {
 	/* lowest priority first */
 	OER_TIMED_PRIORITY_WALL = 1,
 	OER_TIMED_PRIORITY_FLOOD,
+	OER_TIMED_PRIORITY_CTCP,
 	OER_TIMED_PRIORITY_NOTICE,
 	OER_TIMED_PRIORITY_PRIVMSG,
 	OER_TIMED_PRIORITY_NORMAL,
@@ -256,7 +257,7 @@ enum OER_FLAGS_TYPE {
 };
 
 #define OER_FLAGS_GLOBAL "bdfglmpqs"
-#define OER_FLAGS_CHANNEL "!aAbcDefFGklLmMnNoOpPqrRsSuUtTvVwx"
+#define OER_FLAGS_CHANNEL "!aAbcDefFGklLmMnNoOpPqrRsSuUtTvVwxX"
 #define OER_FLAGS_ADMIN "dn"
 #define OER_FLAGS_USER "!adfmovrx"
 
@@ -357,7 +358,7 @@ enum OER_FLAGS_TYPE {
 #define OER_SERVER_IS_STONED "stoned server"
 #define OER_INTERNAL_DYNAMIC_ADMIN "*INTDYN*"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer version 1.0-53, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer version 1.0-54, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -576,6 +577,7 @@ struct channel {
 	int bantype;
 	int allhostsknown;
 	int whoquery;
+	int requestop_now;
 	time_t rejoin_at;
 	time_t last_quote;
 	time_t join_ts;
