@@ -964,6 +964,7 @@ void parseirc(char *serveroutput)
 				/* check if the last user on channel was de-opped, if
 				   so activate requestop */
 				if(ischanopless(this)) {
+					this->requestop_now = 1;
 					this->requestop = mystate->now + 300;
 				}
 				if(isme(target)) {
@@ -1708,6 +1709,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parsecommand->QUIT\n");
 #endif
+		restptr = commandline + prevppos;
 		if(!isopa(userhost)) {
 			return;
 		}
@@ -2016,6 +2018,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parsecommand->MASSMESSAGE\n");
 #endif
+		restptr = commandline + prevppos;
 		if(!isopa(userhost)) {
 			return;
 		}
@@ -2192,10 +2195,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 #endif
                 proceed = (isopa(userhost)) ? 1 : 0;
 		for(that = mystate->channels; that != NULL && !proceed; that = that->next) {
-			if(haschanflags(that, "U") && !isatleastop(that, nick, userhost)) {
-				continue;
-			}
-			if(isatleastopnow(that, nick, userhost)) {
+			if(isadmin(that, userhost)) {
 				proceed = 1;
 			}
 		}
@@ -2211,10 +2211,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 #endif
                 proceed = (isopa(userhost)) ? 1 : 0;
 		for(that = mystate->channels; that != NULL && !proceed; that = that->next) {
-			if(haschanflags(that, "U") && !isatleastop(that, nick, userhost)) {
-				continue;
-			}
-			if(isatleastopnow(that, nick, userhost)) {
+			if(isadmin(that, userhost)) {
 				proceed = 1;
 			}
 		}
@@ -2297,12 +2294,13 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if((this = getchptr(channel)) == NULL) {
 			return;
 		}
-		if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
+		if(haschanflags(this, "X") && !isadmin(this, userhost)) {
+			return;
+		} else if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
+			return;
+		} else if(!isatleastopnow(this, nick, userhost)) {
 			return;
 		}
-                if(!isatleastopnow(this, nick, userhost)) {
-                        return;
-                }
 		if(strlen(restptr) > 0) {
 			snprintf(outstring, WRITE_BUFFER_LENGTH, "%cACTION %s%c", 1, restptr, 1);
 			sendreply(channel, 1, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
@@ -2315,12 +2313,13 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if((this = getchptr(channel)) == NULL) {
 			return;
 		}
-		if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
+		if(haschanflags(this, "X") && !isadmin(this, userhost)) {
+			return;
+		} else if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
+			return;
+		} else if(!isatleastopnow(this, nick, userhost)) {
 			return;
 		}
-                if(!isatleastopnow(this, nick, userhost)) {
-                        return;
-                }
 		if(strlen(restptr) > 0) {
 			sendreply(channel, 1, 0, OER_TIMED_PRIORITY_NORMAL, restptr);
 		}
@@ -2329,6 +2328,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parsecommand->RAW\n");
 #endif
+		restptr = commandline + prevppos;
 		if(!isopa(userhost)) {
 			return;
 		}
